@@ -152,23 +152,27 @@ class ActiveTrainingIO:
         current_json_file_index = self.load_detections_upload_file_index()
         for i in range(current_json_file_index, num_files):
             detections = self.load_detections(i)
-            logging.info(f'uploading detections {i}/{num_files}')
+            logging.info(f'uploading detections in file {i}/{num_files}')
             await self._upload_detections_batched(self.context, detections)
             self.save_detections_upload_file_index(i+1)
 
     async def _upload_detections_batched(self, context: Context, detections: List[Detections]):
-        batch_size = 10
+        batch_size = 100
         skip_detections = self.load_detection_upload_progress()
         for i in range(skip_detections, len(detections), batch_size):
-            up_progress = i+batch_size
-            batch_detections = detections[i:up_progress]
-            dict_detections = [jsonable_encoder(asdict(detection)) for detection in batch_detections]
-            logging.info(f'uploading detections. File size : {len(json.dumps(dict_detections))}')
-            await self._upload_detections(context, batch_detections, up_progress)
+            up_progress = i + batch_size if i + batch_size < len(detections) else 0
+            batch_detections = detections[i:i + batch_size]
+            await self._upload_detections_and_save_progress(context, batch_detections, up_progress)
             skip_detections = up_progress
 
-    async def _upload_detections(self, context: Context, batch_detections: List[Detections], up_progress: int):
+        logging.info('uploaded %d detections', len(detections))
+
+    async def _upload_detections_and_save_progress(self, context: Context, batch_detections: List[Detections], up_progress: int):
+        if len(batch_detections) == 0:
+            print('skipping empty batch', flush=True)
+            return
         detections_json = [jsonable_encoder(asdict(detections)) for detections in batch_detections]
+        print(f'uploading {len(detections_json)} detections', flush=True)
         response = await self.loop_communicator.post(
             f'/{context.organization}/projects/{context.project}/detections', json=detections_json)
         if response.status_code != 200:
@@ -177,7 +181,4 @@ class ActiveTrainingIO:
             raise Exception(msg)
 
         logging.info('successfully uploaded detections')
-        if up_progress > len(batch_detections):
-            self.save_detection_upload_progress(0)
-        else:
-            self.save_detection_upload_progress(up_progress)
+        self.save_detection_upload_progress(up_progress)
